function R = EarthVector(t)
% Cartesian coordinates of the earth in the equatorial-heliocentric
% system the input is a column vector with Julian time

format longg;
d = t - 2451543.5;
w = 282.9404 + (4.70935e-5)*d;      %Longitud del perihelio b
w = w*(pi/180);
w = wrapTo2Pi(w);
a = 1.00000261;     %a = 1.0000000
e = 0.016709 - (1.151e-9)*d;
M = 356.0470 + (0.9856002585) * d;
M = wrapTo2Pi(M * pi/180);
obli = 23.4393 - (3.563e-7)*d;
obli = obli*pi/180;

E = zeros(size(M));
for i=1:length(M)
    E(i) = wrapTo2Pi(keplerEquation(e(i),M(i)));      %eccentric anomaly
end
x = a*(cos(E)-e);
y=zeros(size(M));
for i=1:length(M)
    y(i) = a*sqrt(1-(e(i))^2)*sin(E(i));
end
r = sqrt(x.^2 + y.^2);
v = wrapTo2Pi(atan2(y,x));
l = wrapTo2Pi(v+w);               
for i=1:length(M)
    x(i) = r(i) * cos(l(i));
    y(i) = r(i) * sin(l(i));
end
z=0;
xp = zeros(1,length(M));
yp = zeros(1,length(M));
zp = zeros(1,length(M));
for i=1:length(M)
    xp(i) = x(i);
    yp(i) = y(i)*cos(obli(i)) - z*sin(obli(i));
    zp(i) = y(i)*sin(obli(i)) + z*cos(obli(i));
end
R=-1*[xp' yp' zp'];

end