function pos = Pobs(t, M)
    % This function compute the position of observer on Earth
    % Input data
    % t = time in Julian Date
    % M = [Long cos sin] example [284.30958 0.996767 +0.082976] for W63
    % where:
    % longitude (in degrees east of Greenwich) and the parallax constants 
    % (rho cos phi' and rho sin phi',where phi' is the geocentric latitude
    % and rho is the geocentric distance in earth radii) for each observatory.
    % see https://www.minorplanetcenter.net/iau/lists/ObsCodesF.html
    
format longg
a = M(2) * (6378.1363/149597870.7);
b = M(3) * (6378.1363/149597870.7);
T = (t - 2451545)/36525;        %Julian centuries from 2000 Jan. 1 12h UT1
AngGwich_o = wrapToPi(1.753368560 + 628.3319706889*T + 6.7707e-6*T^2 - 4.5e-10*T^3); 
rotearth = 6.30038736;   %Earth rotational velocity rad/day 
UT1h = JD2UT(t);
UT1 = UT1h(3) - floor(UT1h(3));
AngGwich = wrapTo2Pi(AngGwich_o + rotearth*UT1);

Angob = wrapTo2Pi( AngGwich + M(1)*pi/180);
x = a*cos(Angob);
y = a*sin(Angob);
z = b;
pos =[x y z];

end
