function res = keplerEquation(e,M)
    
    % This function solves Kepler's equation, 
    % is based on Danby's book section 6.6
    % Inputs e: Eccentricity
    %        M: Mean anomaly
    
    format longg
    function res = f(x)
            res = x-e*sin(x)-M;
    end
    function res = fp(x)
            res = 1-e*cos(x);
    end
    function res = fw(x)
            res= e*sin(x);
    end
    function res = fr(x)
            res=e*cos(x);
    end
    Masteris = M - floor(M/(2*pi))*2*pi;  
    sigma = sign(sin(Masteris));
    x0 = Masteris +sigma*0.85*e;  
    er = 1e-15;
    u = 1;
    x = x0;  
    k = 0;
    while u == 1
        k = k + 1;
        delta = -1*f(x)/fp(x);
        aux = x;
        delt = -1*f(x)/(fp(x) + 0.5*delta*fw(x));
        de = -1*f(x)/(fp(x) + 0.5*delt*fw(x) + (1/6)*delt*delt*fr(x));
        x = x + de;
        if (abs(x-aux)<er)||(abs(f(x))<1e-12)
            u = 0;
        end 
        if k>30
            u = 0;
            error('myApp:argChk','\nIt does not converge, there may be an error in the input data\n')
        end
        
    end
    res=x;       
    a = 0;
end